<?php
/**
*
* @package phpBB Extension - PM REG Notify
* @copyright (c) 2016 Stoker
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\pmregnotify\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\config\config */
	protected $config;
	
	/** @var \phpbb\request\request */
	protected $request;

	/** @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	*
	* @param \phpbb\template\template			$template
	* @param \phpbb\config\config				$config
	* @param \phpbb\user						$user
	*/
	public function __construct(\phpbb\template\template $template, \phpbb\config\config $config, \phpbb\request\request $request, \phpbb\user $user)
	{
		$this->template = $template;
		$this->config 	= $config;
		$this->request 	= $request;
		$this->user 	= $user;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup' 						=> 'load_language_on_setup',
			'core.page_header'						=> 'add_page_header_link',
			'core.ucp_prefs_personal_data'			=> 'ucp_prefs_get_data',
			'core.ucp_prefs_personal_update_data'	=> 'ucp_prefs_set_data',
		);
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'stoker/pmregnotify',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function add_page_header_link($event)
	{
		$this->template->assign_vars(array(
			'ENABLE_PMREGNOTIFY_REG'		=> $this->config['enable_pmregnotify_reg'] ? true : false,
			'ENABLE_PMREGNOTIFY_REG_FA'		=> $this->config['enable_pmregnotify_reg_fa'] ? true : false,
			'ENABLE_PMREGNOTIFY_PM'			=> $this->config['enable_pmregnotify_pm'] ? true : false,
			'ENABLE_PMREGNOTIFY_PM_USER'	=> $this->config['enable_pmregnotify_pm_user'] ? true : false,
			'ENABLE_PMREGNOTIFY_PM_AVATAR'	=> $this->config['enable_pmregnotify_pm_avatar'] ? true : false,
			'ENABLE_PMREGNOTIFY_PM_FA'		=> $this->config['enable_pmregnotify_pm_fa'] ? true : false,
			'L_PMREGNOTIFY_WELCOME_SITE'	=> $this->user->lang('PMREGNOTIFY_WELCOME_SITE', $this->config['sitename']),
			'L_PMREGNOTIFY_WELCOME_USER'	=> $this->user->lang('PMREGNOTIFY_WELCOME_USER', $this->user->data['username']),
			'S_PMREGNOTIFY'					=> !empty($this->user->data['user_pmregnotify']) ? true : false,
		));
	}
	
	/**
	* Get user's option and display it in UCP Prefs View page
	*
	* @param object $event The event object
	* @return null
	* @access public
	*/
	public function ucp_prefs_get_data($event)
	{
		// Request the user option vars and add them to the data array
		$event['data'] = array_merge($event['data'], array(
			'pmregnotify'	=> $this->request->variable('pmregnotify', (int) $this->user->data['user_pmregnotify']),
		));

		// Output the data vars to the template (except on form submit)
		if (!$event['submit'])
		{
			$this->user->add_lang_ext('stoker/pmregnotify', 'pmregnotify_ucp');
			$this->template->assign_vars(array(
				'S_UCP_PMREGNOTIFY'		=> $event['data']['pmregnotify'],
			));
		}
	}

	/**
	* Add user's welcome option state into the sql_array
	*
	* @param object $event The event object
	* @return null
	* @access public
	*/
	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'user_pmregnotify'	=> $event['data']['pmregnotify'],
		));
	}
}